@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef FORMMAIN_H
@@ -25,13 +25,13 @@
 #include <QMenu>
 #include <QUrl>
 #include "formdocument.h"
-   
+
 // forward definitions
 class QAction;
+class QMdiArea;
 class QMenu;
 class QMenuBar;
 class QStatusBar;
-class QWorkspace;
 class QSignalMapper;
 
 class CPrefs;
@@ -77,12 +77,13 @@ protected slots:
     virtual void slotHandbook();
 
     virtual void slotLanguage();
+    virtual void slotSetActiveWindow(QWidget *widget);
     virtual void slotUpdateDocumentMenus();
     virtual void slotUpdateWindowMenu();
 
 protected:
     /** The workspace */
-    QWorkspace *workspace;
+    QMdiArea *workspace;
 
     /** The signal mapper */
     QSignalMapper *windowMapper;
@@ -127,10 +128,10 @@ protected:
     QAction *actionTile;
     /** Cascade document windows */
     QAction *actionCascade;
-    
+
     /** Display the handbook */
     QAction *actionHandbook;
-    
+
     /** Create a new boat */
     QAction *actionNewBoat;
     /** Create a new hull */
@@ -141,14 +142,14 @@ protected:
     QAction *actionNewSail;
     /** Open an existing sail definition */
     QAction *actionOpen;
-    
+
     /** Save the sail definition to a file */
     QAction *actionSave;
     /** Prompt for a filename then write the sail definition to a file */
     QAction *actionSaveAs;
     /** Final separator in the 'File' menu before 'Quit' */
     QAction *actionFileSep;
-    
+
     /** View the sail definition */
     QAction *actionViewDef;
     /** View the sail mould */
