@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "formmould.h"
@@ -45,7 +45,7 @@ CFormMould::CFormMould( QWidget *parent, CSailMould *mouldptr )
     // the user clicks OK
     sailmould = mouldptr;
 
-    setSizeGripEnabled( TRUE );
+    setSizeGripEnabled( true );
     QGridLayout* CFormMouldLayout = new QGridLayout( this );
 
     // Add the buttons at the bottom of the screen
@@ -54,7 +54,7 @@ CFormMould::CFormMould( QWidget *parent, CSailMould *mouldptr )
     buttonsLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum ) );
 
     buttonOk = new QPushButton( tr("&OK"), this );
-    buttonOk->setDefault( TRUE );
+    buttonOk->setDefault( true );
     buttonsLayout->addWidget( buttonOk );
 
     buttonCancel = new QPushButton( tr("&Cancel"), this );
