@@ -1,24 +1,22 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifdef HAVE_QTOPENGL
-
 #include <cmath>
 #include <QMouseEvent>
 #include "saildispgl.h"
@@ -96,7 +94,7 @@ void CSailDispGL::draw( const CPanelGroup &sail )
     {
         if ( sail.type == HULL )
         {
-            /**  Hull GL color dark green (.1, .3, .2) 
+            /**  Hull GL color dark green (.1, .3, .2)
                  color lighter green  (.1, .5, .2) */
             glColor3f(.1, .5, .2);
         }
@@ -214,5 +212,3 @@ void CSailDispGL::wheelEvent( QWheelEvent *event)
         zoomOut();
     redraw();
 }
-
-#endif
