@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <cmath>
@@ -53,8 +53,8 @@ void CSailPainter::draw(const CPanel &panel)
     if (panel.hasHems)
     {
         // switch pen to red
-        QPen oldpen = pen();
-        setPen(Qt::red);
+        const QPen oldPen = pen();
+        setPenColor(Qt::red);
 
         poly = QPolygonF();
         for (iter = panel.cutBottom.begin(); iter != panel.cutBottom.end(); iter++)
@@ -68,7 +68,7 @@ void CSailPainter::draw(const CPanel &panel)
         drawPolyline(poly);
 
         // reset pen color
-        setPen(oldpen);
+        setPen(oldPen);
     }
 }
 
@@ -88,13 +88,13 @@ void CSailPainter::draw(const CPanelGroup &sail)
     unsigned int i;
 
     // set pen color
-    QPen oldpen = pen();
+    const QPen oldPen = pen();
     if ( sail.type == HULL )
-        setPen(Qt::darkGreen);
+        setPenColor(Qt::darkGreen);
     else if ( sail.type == RIG )
-        setPen(Qt::darkRed);
+        setPenColor(Qt::darkRed);
     else
-        setPen(Qt::blue);
+        setPenColor(Qt::blue);
 
     for (i = 0; i < sail.size(); i++)
         draw(sail[i]);
@@ -102,7 +102,7 @@ void CSailPainter::draw(const CPanelGroup &sail)
         draw(sail.child[i]);
 
     // reset pen color
-    setPen(oldpen);
+    setPen(oldPen);
 }
 
 
@@ -319,6 +319,27 @@ void CSailPainter::setFontSize(const real size, const real zoom)
     setFont(myfont);
 }
 
+/** Set the pen color.
+ *
+ * Unlike setPen(QColor), this does not change the pen width.
+ */
+void CSailPainter::setPenColor(const QColor &color)
+{
+    QPen p = pen();
+    p.setColor(color);
+    setPen(p);
+}
+
+/** Set the default pen width.
+ *
+ * The width is set to 0, indicating a 1 pixel cosmetic pen.
+ */
+void CSailPainter::setPenWidth()
+{
+    QPen p = pen();
+    p.setWidth(0);
+    setPen(p);
+}
 
 /** Set coordinate system to match the logical viewport.
  *
