@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef SAILPAINTER_H
@@ -56,6 +56,8 @@ public:
     void drawMarkers(const CPanelGroup &sail);
 
     void setFontSize(const real size, const real zoom);
+    void setPenColor(const QColor &color);
+    void setPenWidth();
     void setWindow(const CRect3d& lRect);
 
     CVector3d textSize(const QStringList &lst);
