@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "sailprinter.h"
@@ -170,6 +170,7 @@ void CSailDevelPrinter::print(CTextPainter *painter, int page, real scale, real
     // set coordinate system to match the logical viewport
     painter->setWindow(logicalRect);
     painter->setFontSize(fontsize, 1);
+    painter->setPenWidth();
 
     painter->draw(sail[page]);
     if (showLabels)
@@ -178,12 +179,12 @@ void CSailDevelPrinter::print(CTextPainter *painter, int page, real scale, real
     painter->drawMarkers(sail[page]);
 
     // mark corners of cloth rectangle
-    QPen oldpen = painter->pen();
-    painter->setPen(Qt::green);
+    const QPen oldPen = painter->pen();
+    painter->setPenColor(Qt::green);
     CRect3d rp = sail[page].boundingRect();
     painter->drawCross(rp.min, painter->fontMetrics().height() );
     painter->drawCoord(rp.min, PI );
-    painter->setPen(oldpen);
+    painter->setPen(oldPen);
 
     /* NOTE scale factor on preview screen is not same value as in spinbox
     *  However the correct value equal to spinbox value will be printed */
@@ -211,7 +212,8 @@ void CSailDrawingPrinter::print(CTextPainter *painter, int, real scale, real fon
     // set coordinate system to match the logical viewport
     painter->setWindow(logicalRect);
     painter->setFontSize(fontsize, 1);
-    
+    painter->setPenWidth();
+
     painter->draw(sail);
     if (showLabels)
         painter->drawLabels(sail);
@@ -234,4 +236,4 @@ double CSailDrawingPrinter::scaleToFit(QPaintDevice* device) const
     const real w = device->widthMM();
     const real h = device->heightMM();
     return 0.8 * w / sail.boundingRect().expandToRatio(w / h).width();
-}
\ No newline at end of file
+}
