@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "sailviewer-panel.h"
@@ -28,9 +28,7 @@
 CSailViewerTabs::CSailViewerTabs(QWidget *parent)
         : QTabWidget(parent)
 {
-#ifdef HAVE_QTOPENGL
     addViewer(new CSailViewerPanel(NULL, SHADED, true));
-#endif
     addViewer(new CSailViewerPanel(NULL, WIREFRAME, true));
 }
 
@@ -56,9 +54,7 @@ void CSailViewerTabs::languageChange()
     int tabidx = 0;
     for (unsigned int i = 0; i < panel.size(); i++)
         panel[i]->languageChange();
-#ifdef HAVE_QTOPENGL
     setTabText(tabidx++, tr("shaded view"));
-#endif
     setTabText(tabidx++, tr("wireframe view"));
 }
 
@@ -71,8 +67,6 @@ void CSailViewerTabs::languageChange()
 void CSailViewerTabs::setObject(const CPanelGroup &obj)
 {
     int tabidx = 0;
-#ifdef HAVE_QTOPENGL
     panel[tabidx++]->setObject(obj);
-#endif
     panel[tabidx++]->setObject(obj);
 }
