@@ -1,32 +1,28 @@
 /*
- * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * Copyright (C) 1993-2015 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-// for HAVE_QSVGGENERATOR
-#include "sailcutqt.h"
-
 #include "sailwriter-svg.h"
 #include "sailprinter.h"
-#ifdef HAVE_QSVGGENERATOR
-#include <QSvgGenerator>
-#endif
 
-/** 
+#include <QSvgGenerator>
+
+/**
  *  Write a 3D sail to 2D SVG format.
  *
  * @param sail the sail to write
@@ -34,13 +30,11 @@
  */
 void CSailSvgWriter::write(const CPanelGroup &sail, const QString &filename) const
 {
-#ifdef HAVE_QSVGGENERATOR
     // SVG generator
     QSvgGenerator generator;
     generator.setFileName(filename);
 
     CTextPainter painter(&generator);
     CSailDrawingPrinter(sail, false).print(&painter, 0, 1.0, 10);
-#endif
 }
 
